@@ -9,7 +9,7 @@ from .account import Account
 from .user import User
 from .token import Token
 
-__version__ = "1.0.25"
+__version__ = "1.0.26"
 
 
 class FreedomClient(object):
@@ -150,6 +150,10 @@ class FreedomClient(object):
         result = self.api.call("DELETE", "/tokens/{}".format(token_id), params=params, **api_call_kwargs)
         return result
 
+    def trace(self, account_id, data: list[dict], **api_call_kwargs):
+        result = self.api.call("PUT", f"/accounts/{account_id}/trace", data={'events': data}, **api_call_kwargs)
+        return result
+
     def report_issue(
             self,
             message,
